@@ -7,6 +7,8 @@ return ``404 Not Found``.
 """
 from paste import httpexceptions
 from paste.util import converters
+import tempfile
+from cStringIO import StringIO
 
 __all__ = ['Cascade']
 
@@ -74,8 +76,33 @@ class Cascade(object):
                 return _consuming_writer
             return start_response(status, headers, exc_info)
 
+        try:
+            length = int(environ.get('CONTENT_LENGTH', 0) or 0)
+        except ValueError:
+            length = 0
+        if length > 0:
+            # We have to copy wsgi.input
+            copy_wsgi_input = True
+            if length > 4096 or length < 0:
+                f = tempfile.TemporaryFile()
+                if length < 0:
+                    f.write(environ['wsgi.input'].read())
+                else:
+                    copy_len = length
+                    while copy_len > 0:
+                        chunk = environ['wsgi.input'].read(min(copy_len, 4096))
+                        f.write(chunk)
+                        copy_len -= len(chunk)
+                f.seek(0)
+            else:
+                f = StringIO(environ['wsgi.input'].read(length))
+            environ['wsgi.input'] = f
+        else:
+            copy_wsgi_input = False
         for app in self.apps[:-1]:
             environ_copy = environ.copy()
+            if copy_wsgi_input:
+                environ_copy['wsgi.input'].seek(0)
             failed = []
             try:
                 v = app(environ_copy, repl_start_response)
@@ -89,6 +116,8 @@ class Cascade(object):
                         v.close()
             except self.catch_exceptions, e:
                 pass
+        if copy_wsgi_input:
+            environ['wsgi.input'].seek(0)
         return self.apps[-1](environ, start_response)
 
 def _consuming_writer(s):
