@@ -134,10 +134,10 @@ class WSGIHandlerMixin:
             #
             send_close = True
             for (k, v) in  headers:
-                k = k.lower()
-                if 'content-length' == k:
+                lk = k.lower()
+                if 'content-length' == lk:
                     send_close = False
-                if 'connection' == k:
+                if 'connection' == lk:
                     if 'close' == v.lower():
                         self.close_connection = 1
                         send_close = False
@@ -293,6 +293,7 @@ class WSGIHandlerMixin:
             finally:
                 if hasattr(result,'close'):
                     result.close()
+                result = None
         except socket.error, exce:
             self.wsgi_connection_drop(exce, environ)
             return
@@ -313,7 +314,7 @@ class WSGIHandlerMixin:
 # http://aspn.activestate.com/ASPN/Cookbook/Python/Recipe/442473
 #
 try:
-    from OpenSSL import SSL
+    from OpenSSL import SSL, tsafe
     SocketErrors = (socket.error, SSL.ZeroReturnError, SSL.SysCallError)
 except ImportError:
     # Do not require pyOpenSSL to be installed, but disable SSL
@@ -359,7 +360,14 @@ else:
                                         self.socket_type)
             self.ssl_context = ssl_context
             if ssl_context:
-                self.socket = SSL.Connection(ssl_context, self.socket)
+                class TSafeConnection(tsafe.Connection):
+                    def settimeout(self, *args):
+                        self._lock.acquire()
+                        try:
+                            return self._ssl_conn.settimeout(*args)
+                        finally:
+                            self._lock.release()
+                self.socket = TSafeConnection(ssl_context, self.socket)
             self.server_bind()
             self.server_activate()
 
@@ -456,9 +464,7 @@ class LimitedLengthFile(object):
         return data
 
     def readline(self, *args):
-        # @@: I can't see any way to keep this from reading past the end
-        # except to implement readline and a buffer privately
-        data = self.file.readline(*args)
+        data = self.file.readline(self.length - self._consumed)
         self._consumed += len(data)
         return data
 
@@ -618,8 +624,9 @@ class ThreadPool(object):
                 if not hasattr(worker, 'thread_id'):
                     # Not initialized
                     continue
-                if worker.thread_id in self.worker_tracker:
-                    time_started, info = self.worker_tracker[worker.thread_id]
+                time_started, info = self.worker_tracker.get(worker.thread_id,
+                                                             (None, None))
+                if time_started is not None:
                     if now - time_started < self.hung_thread_limit:
                         busy += 1
             if busy < self.spawn_if_under:
@@ -659,8 +666,9 @@ class ThreadPool(object):
                 # The worker hasn't fully started up, we should just
                 # ignore it
                 continue
-            if worker.thread_id in self.worker_tracker:
-                time_started, info = self.worker_tracker[worker.thread_id]
+            time_started, info = self.worker_tracker.get(worker.thread_id,
+                                                         (None, None))
+            if time_started is not None:
                 if now - time_started > self.hung_thread_limit:
                     result['hung'].append(worker)
                 else:
@@ -738,12 +746,13 @@ class ThreadPool(object):
                 # Not setup yet
                 starting_workers += 1
                 continue
-            if worker.thread_id not in self.worker_tracker:
+            time_started, info = self.worker_tracker.get(worker.thread_id,
+                                                         (None, None))
+            if time_started is None:
                 # Must be idle
                 idle_workers += 1
                 continue
             working_workers += 1
-            time_started, info = self.worker_tracker[worker.thread_id]
             max_time = max(max_time, now-time_started)
             total_time += now-time_started
             if now - time_started > self.kill_thread_limit:
@@ -1117,7 +1126,7 @@ class ServerExit(SystemExit):
 def serve(application, host=None, port=None, handler=None, ssl_pem=None,
           ssl_context=None, server_version=None, protocol_version=None,
           start_loop=True, daemon_threads=None, socket_timeout=None,
-          use_threadpool=True, threadpool_workers=10,
+          use_threadpool=None, threadpool_workers=10,
           threadpool_options=None):
     """
     Serves your ``application`` over HTTP(S) via WSGI interface
@@ -1143,7 +1152,7 @@ def serve(application, host=None, port=None, handler=None, ssl_pem=None,
         This an optional SSL certificate file (via OpenSSL). You can
         supply ``*`` and a development-only certificate will be
         created for you, or you can generate a self-signed test PEM
-        certificate file as follows:
+        certificate file as follows::
 
             $ openssl genrsa 1024 > host.key
             $ chmod 400 host.key
@@ -1226,7 +1235,7 @@ def serve(application, host=None, port=None, handler=None, ssl_pem=None,
             else:
                 ssl_context = SSL.Context(SSL.SSLv23_METHOD)
                 ssl_context.use_privatekey_file(ssl_pem)
-                ssl_context.use_certificate_file(ssl_pem)
+                ssl_context.use_certificate_chain_file(ssl_pem)
 
     host = host or '127.0.0.1'
     if not port:
@@ -1245,6 +1254,8 @@ def serve(application, host=None, port=None, handler=None, ssl_pem=None,
         assert protocol_version in ('HTTP/0.9', 'HTTP/1.0', 'HTTP/1.1')
         handler.protocol_version = protocol_version
 
+    if use_threadpool is None:
+        use_threadpool = True
 
     if converters.asbool(use_threadpool):
         server = WSGIThreadPoolServer(application, server_address, handler,
