@@ -290,27 +290,21 @@ class Registry(object):
     
     def register(self, stacked, obj):
         """Register an object with a StackedObjectProxy"""
+        myreglist = self.reglist[-1]
+        stacked_id = id(stacked)
+        if stacked_id in myreglist:
+            stacked._pop_object(myreglist[stacked_id][1])
+            del myreglist[stacked_id]
         stacked._push_object(obj)
-        myreglist = self.reglist[-1]
-        myreglist[id(stacked)] = (stacked, obj)
-
-    def replace(self, stacked, obj):
-        """Replace the object referenced by a StackedObjectProxy with a
-        different object
-
-        In the event that no object has been registered, the new object will
-        be registered.
-        """
-        myreglist = self.reglist[-1]
-        if id(stacked) in myreglist:
-            stacked._pop_object(myreglist[id(stacked)][1])
-        self.register(stacked, obj)
+        myreglist[stacked_id] = (stacked, obj)
+    
+    # Replace now does the same thing as register
+    replace = register
     
     def cleanup(self):
         """Remove all objects from all StackedObjectProxy instances that
         were tracked at this Registry context"""
-        for id, val in self.reglist[-1].iteritems():
-            stacked, obj = val
+        for stacked, obj in self.reglist[-1].itervalues():
             stacked._pop_object(obj)
         self.reglist.pop()
         
