@@ -227,7 +227,7 @@ def catch_errors_app(application, environ, start_response, error_callback_app,
         return error_callback_app(environ, start_response, sys.exc_info())
     if type(app_iter) in (list, tuple):
         # These won't produce exceptions
-        if ok_callback:
+        if ok_callback is not None:
             ok_callback()
         return app_iter
     else:
@@ -530,7 +530,7 @@ def intercept_output(environ, application, conditional=None,
     def replacement_start_response(status, headers, exc_info=None):
         if conditional is not None and not conditional(status, headers):
             data.append(None)
-            return start_response(status, headers)
+            return start_response(status, headers, exc_info)
         if data:
             data[:] = []
         data.append(status)
